"""
The sgpv-module is a translation of the same named R-library of the same name.
The original R-library can be found here https://github.com/weltybiostat/sgpv
The authors of the R-library and this module for Python are not connected with each other.
There is a translation of the R-library into Stata with additional features by the author of this module.
The Stata version of this module can be found here https://github.com/skbormann/stata-tools/tree/master/sgpv

This module contains the following functions:
            value   - calculate the SGPVs
            power   - power functions for the SGPVs
            risk    - false confirmation/discovery risks for the SGPVs
            plot    - plot the SGPVs
            data    - load the example dataset 

"""
